@@ -59,7 +59,8 @@ static void print_arguments(GString *gstr, const char *sig,
 
 	for (i = 0; sig[i]; i++) {
 		char type[32];
-		int len, struct_level, dict_level;
+		int struct_level, dict_level;
+		unsigned int len;
 		gboolean complete;
 
 		complete = FALSE;
@@ -493,6 +494,9 @@ gboolean g_dbus_unregister_interface(DBusConnection *connection,
 	struct generic_data *data = NULL;
 	struct interface_data *iface;
 
+	if (!path)
+		return FALSE;
+
 	if (dbus_connection_get_object_path_data(connection, path,
 						(void *) &data) == FALSE)
 		return FALSE;
